@@ -62,6 +62,7 @@ from neutron_lib.api.definitions import l3_port_ip_change_not_allowed
 from neutron_lib.api.definitions import logging
 from neutron_lib.api.definitions import logging_resource
 from neutron_lib.api.definitions import metering
+from neutron_lib.api.definitions import metering_source_and_destination_filters
 from neutron_lib.api.definitions import multiprovidernet
 from neutron_lib.api.definitions import network
 from neutron_lib.api.definitions import network_availability_zone
@@ -71,6 +72,7 @@ from neutron_lib.api.definitions import network_mtu_writable
 from neutron_lib.api.definitions import network_segment_range
 from neutron_lib.api.definitions import pagination
 from neutron_lib.api.definitions import port
+from neutron_lib.api.definitions import port_device_profile
 from neutron_lib.api.definitions import port_mac_address_regenerate
 from neutron_lib.api.definitions import port_numa_affinity_policy
 from neutron_lib.api.definitions import port_resource_request
@@ -98,6 +100,7 @@ from neutron_lib.api.definitions import router_interface_fip
 from neutron_lib.api.definitions import routerservicetype
 from neutron_lib.api.definitions import security_groups_normalized_cidr
 from neutron_lib.api.definitions import security_groups_port_filtering
+from neutron_lib.api.definitions import security_groups_remote_address_group
 from neutron_lib.api.definitions import segment
 from neutron_lib.api.definitions import segments_peer_subnet_host_routes
 from neutron_lib.api.definitions import servicetype
@@ -177,6 +180,7 @@ _ALL_API_DEFINITIONS = {
     logging,
     logging_resource,
     metering,
+    metering_source_and_destination_filters,
     multiprovidernet,
     network,
     network_availability_zone,
@@ -186,6 +190,7 @@ _ALL_API_DEFINITIONS = {
     network_segment_range,
     pagination,
     port,
+    port_device_profile,
     port_mac_address_regenerate,
     port_numa_affinity_policy,
     port_resource_request,
@@ -213,6 +218,7 @@ _ALL_API_DEFINITIONS = {
     routerservicetype,
     security_groups_normalized_cidr,
     security_groups_port_filtering,
+    security_groups_remote_address_group,
     segment,
     segments_peer_subnet_host_routes,
     servicetype,
